import React from "./_snowpack/pkg/react.js";
import ReactDOM from "./_snowpack/pkg/react-dom.js";
import GraphiQL from "./_snowpack/pkg/graphiql-sudograph.js";
import {parse} from "./_snowpack/pkg/graphql.js";
import {
  sudograph
} from "./sudograph.js";
class SudoPlayground extends HTMLElement {
  get canisterIdLocal() {
    return this.getAttribute("canister-id-local");
  }
  get canisterIdIc() {
    return this.getAttribute("canister-id-ic");
  }
  get originLocal() {
    return this.getAttribute("origin-local");
  }
  get originIc() {
    return this.getAttribute("origin-ic");
  }
  get queryFunctionName() {
    return this.getAttribute("query-function-name");
  }
  get mutationFunctionName() {
    return this.getAttribute("mutation-function-name");
  }
  constructor() {
    super();
    this.innerHTML = `
            <link href="https://unpkg.com/graphiql/graphiql.min.css" rel="stylesheet" />
        `;
  }
  async connectedCallback() {
    const div = document.createElement("div");
    div.style.height = "100vh";
    document.body.appendChild(div);
    setTimeout(() => {
      const environment = getEnvironment(this.originLocal, this.originIc);
      ReactDOM.render(React.createElement(GraphiQL, {
        fetcher: graphQLFetcher(environment === "ic" ? this.canisterIdIc : this.canisterIdLocal, this.queryFunctionName, this.mutationFunctionName)
      }), div);
    }, 1e3);
  }
}
window.customElements.define("sudo-playground", SudoPlayground);
function graphQLFetcher(canisterId, queryFunctionName, mutationFunctionName) {
  return async (graphQLParams) => {
    const {
      query,
      mutation
    } = sudograph({
      canisterId,
      queryFunctionName,
      mutationFunctionName
    });
    const queryOrMutation = getQueryOrMutation(graphQLParams.query);
    const result = queryOrMutation === "QUERY" ? await query(graphQLParams.query, graphQLParams.variables) : await mutation(graphQLParams.query, graphQLParams.variables);
    return result;
  };
}
function getQueryOrMutation(queryString) {
  const ast = parse(queryString);
  const firstDefinition = ast.definitions[0];
  if (firstDefinition === void 0) {
    return "QUERY";
  }
  return firstDefinition.operation === "query" ? "QUERY" : "MUTATION";
}
function getEnvironment(originLocal, originIc) {
  if (window.location.origin === originLocal || window.location.origin.endsWith("localhost:8000")) {
    return "local";
  }
  if (window.location.origin === originIc || window.location.origin.endsWith("ic0.app")) {
    return "ic";
  }
}
